@@ -4,9 +4,11 @@
 # https://github.com/ncss-tech/soilDB/issues/36
 
 get_component_from_SDA <- function(WHERE = NULL, duplicates = FALSE, childs = TRUE, 
-                                   drop.unused.levels = TRUE,
+                                   droplevels = TRUE,
                                    stringsAsFactors = default.stringsAsFactors()
                                    ) {
+  if(!duplicates & grepl(WHERE, pattern = "mukey")[1])
+    warning("duplicates is set to FALSE and 'mukey' is in WHERE clause. Note: 'mukey' omitted from result.", call.=FALSE)
   
   # SDA is missing soiltempa_r AS mast_r
   # Joining in the fetch on derived_cokey doesn't work but should. There are duplicate components with the same combination of elements.
@@ -42,7 +44,7 @@ get_component_from_SDA <- function(WHERE = NULL, duplicates = FALSE, childs = TR
   
   # recode metadata domains
   d.component <- uncode(d.component, db = "SDA", 
-                        drop.unused.levels = drop.unused.levels,
+                        droplevels = droplevels,
                         stringsAsFactors = stringsAsFactors
                         )
 
@@ -134,7 +136,7 @@ get_component_from_SDA <- function(WHERE = NULL, duplicates = FALSE, childs = TR
 
 
 get_cointerp_from_SDA <- function(WHERE = NULL, mrulename = NULL, duplicates = FALSE, 
-                                  drop.unused.levels = TRUE,
+                                  droplevels = TRUE,
                                   stringsAsFactors = default.stringsAsFactors()
                                   ) {
   
@@ -172,7 +174,7 @@ get_cointerp_from_SDA <- function(WHERE = NULL, mrulename = NULL, duplicates = F
   
   # recode metadata domains
   d.cointerp <- uncode(d.cointerp, db = "SDA", 
-                       drop.unused.levels = drop.unused.levels,
+                       droplevels = droplevels,
                        stringsAsFactors = stringsAsFactors
                        )
   
@@ -180,7 +182,7 @@ get_cointerp_from_SDA <- function(WHERE = NULL, mrulename = NULL, duplicates = F
   }
 
 
-get_legend_from_SDA <- function(WHERE = NULL, drop.unused.levels = TRUE, stringsAsFactors = default.stringsAsFactors()) {
+get_legend_from_SDA <- function(WHERE = NULL, droplevels = TRUE, stringsAsFactors = default.stringsAsFactors()) {
   q.legend  <- paste("
                      SELECT
                      mlraoffice, areasymbol, areaname, areatypename, CAST(areaacres AS INTEGER) AS areaacres, ssastatus, 
@@ -203,7 +205,7 @@ get_legend_from_SDA <- function(WHERE = NULL, drop.unused.levels = TRUE, strings
   # recode metadata domains
   d.legend <- uncode(d.legend,
                      db = "SDA", 
-                     drop.unused.levels = drop.unused.levels,
+                     droplevels = droplevels,
                      stringsAsFactors   = stringsAsFactors
   )
   
@@ -214,7 +216,7 @@ get_legend_from_SDA <- function(WHERE = NULL, drop.unused.levels = TRUE, strings
 
 
 
-get_lmuaoverlap_from_SDA <- function(WHERE = NULL, drop.unused.levels = TRUE, stringsAsFactors = default.stringsAsFactors()) {
+get_lmuaoverlap_from_SDA <- function(WHERE = NULL, droplevels = TRUE, stringsAsFactors = default.stringsAsFactors()) {
 
   q <- paste("SELECT
              legend.areasymbol, legend.areaname, legend.areaacres, 
@@ -247,7 +249,7 @@ get_lmuaoverlap_from_SDA <- function(WHERE = NULL, drop.unused.levels = TRUE, st
   # recode metadata domains
   d <- uncode(d,
               db = "NASIS", 
-              drop.unused.levels = drop.unused.levels,
+              droplevels = droplevels,
               stringsAsFactors = stringsAsFactors
   )
   
@@ -258,7 +260,7 @@ get_lmuaoverlap_from_SDA <- function(WHERE = NULL, drop.unused.levels = TRUE, st
 
 
 get_mapunit_from_SDA <- function(WHERE = NULL, 
-                                 drop.unused.levels = TRUE,
+                                 droplevels = TRUE,
                                  stringsAsFactors = default.stringsAsFactors()
                                  ) {
 
@@ -296,7 +298,7 @@ get_mapunit_from_SDA <- function(WHERE = NULL,
   # recode metadata domains
   d.mapunit <- uncode(d.mapunit, 
                       db = "SDA", 
-                      drop.unused.levels = drop.unused.levels,
+                      droplevels = droplevels,
                       stringsAsFactors   = stringsAsFactors
                       )
   
@@ -314,7 +316,7 @@ get_mapunit_from_SDA <- function(WHERE = NULL,
 get_chorizon_from_SDA <- function(WHERE = NULL, duplicates = FALSE, 
                                   childs = TRUE, 
                                   nullFragsAreZero = TRUE, 
-                                  drop.unused.levels = TRUE,
+                                  droplevels = TRUE,
                                   stringsAsFactors = default.stringsAsFactors()
                                   ) {
 
@@ -368,7 +370,7 @@ get_chorizon_from_SDA <- function(WHERE = NULL, duplicates = FALSE,
     if (stringsAsFactors == TRUE) {
       texcl = factor(tolower(texcl), levels = metadata[metadata$ColumnPhysicalName == "texcl", "ChoiceName"])
       }
-    if (drop.unused.levels == drop.unused.levels & is.factor(texcl)) {
+    if (droplevels == droplevels & is.factor(texcl)) {
       texcl = droplevels(texcl)
       }
     })
@@ -500,24 +502,24 @@ get_chorizon_from_SDA <- function(WHERE = NULL, duplicates = FALSE,
 }
 
 
-get_diagnostics_from_SDA <- function(target_cokeys) {
+.get_diagnostics_from_SDA <- function(target_cokeys) {
   # query SDA to get corresponding codiagfeatures
   q <- paste0('SELECT * FROM codiagfeatures WHERE cokey IN ', format_SQL_in_statement(target_cokeys), ";")
   return(SDA_query(q))
 }
 
-fetchSDA_component <- function(WHERE = NULL, duplicates = FALSE, childs = TRUE, 
-                               nullFragsAreZero = TRUE, 
-                               rmHzErrors = FALSE,
-                               drop.unused.levels = TRUE,
-                               stringsAsFactors = default.stringsAsFactors()
-                               ) {
+fetchSDA <- function(WHERE = NULL, duplicates = FALSE, childs = TRUE, 
+                     nullFragsAreZero = TRUE, 
+                     rmHzErrors = FALSE,
+                     droplevels = TRUE,
+                     stringsAsFactors = default.stringsAsFactors()
+                     ) {
 
   # load data in pieces
   f.component <- get_component_from_SDA(WHERE, 
                                         duplicates = duplicates, 
                                         childs = childs, 
-                                        drop.unused.levels = drop.unused.levels,
+                                        droplevels = droplevels,
                                         stringsAsFactors = stringsAsFactors
                                         )
   # f.mapunit   <- get_mapunit_from_SDA(WHERE, stringsAsFactors = stringsAsFactors)
@@ -525,15 +527,18 @@ fetchSDA_component <- function(WHERE = NULL, duplicates = FALSE, childs = TRUE,
   # AGB update: only query component horizon for cokeys in the component result (subject to user-specified WHERE clause)
   f.chorizon  <- get_chorizon_from_SDA(paste0('c.cokey IN', format_SQL_in_statement(unique(f.component$cokey))), 
                                        duplicates = duplicates, 
-                                       drop.unused.levels = drop.unused.levels
+                                       droplevels = droplevels
                                        )
   
   # diagnostic features  
-  f.diag <- get_diagnostics_from_SDA(f.component$cokey)
+  f.diag <- .get_diagnostics_from_SDA(f.component$cokey)
   
   # optionally test for bad horizonation... flag, and remove
   if (rmHzErrors) {
-    f.chorizon.test <- plyr::ddply(f.chorizon, 'cokey', test_hz_logic, topcol='hzdept_r', bottomcol='hzdepb_r', strict=TRUE)
+    f.chorizon.test <- plyr::ddply(f.chorizon, 'cokey', function(d) {
+      res <- aqp::hzDepthTests(top=d[['hzdept_r']], bottom=d[['hzdepb_r']])
+      return(all(!res))
+    })
     
     # which are the good (valid) ones?
     good.ids <- as.character(f.chorizon.test$cokey[which(f.chorizon.test$hz_logic_pass)])
@@ -560,6 +565,10 @@ fetchSDA_component <- function(WHERE = NULL, duplicates = FALSE, childs = TRUE,
   # set SDA/SSURGO-specific horizon identifier
   hzidname(f.chorizon) <- 'chkey'
   
+  # set optional hz designation and texture slots
+  hzdesgnname(f.chorizon) <- "hzname"
+  hztexclname(f.chorizon) <- "texture"
+  
   # add diagnostics
   if(is.data.frame(f.diag)) {
     diagnostic_hz(f.chorizon) <- f.diag
