@@ -12,6 +12,16 @@ get_cosoilmoist_from_NASISWebReport <- function(projectname, impute = TRUE, stri
   # set factor levels according to metadata domains
   d.cosoilmoist <- uncode(d.cosoilmoist, db = "LIMS", stringsAsFactors = stringsAsFactors)
   
+  # refactoring frequency levels, not sure why these aren't sorted naturally
+  flod_lev <- levels(d.cosoilmoist$flodfreqcl)
+  pond_lev <- levels(d.cosoilmoist$pondfreqcl)
+  d.cosoilmoist <- within(d.cosoilmoist, {
+    flodfreqcl = levels(flodfreqcl)[as.integer(flodfreqcl)]
+    flodfreqcl = factor(flodfreqcl, levels = flod_lev[c(1, 5, 2, 7, 3, 4, 6)])
+    pondfreqcl = levels(pondfreqcl)[as.integer(pondfreqcl)]
+    pondfreqcl = factor(pondfreqcl, levels = pond_lev[c(1, 5, 2, 7, 3, 4, 6)])
+  })
+  
   # prep dataset: rename columns, impute empty values, stringsAsFactors
   d.cosoilmoist <- .cosoilmoist_prep(d.cosoilmoist, impute = impute, stringsAsFactors = stringsAsFactors)
   
