@@ -61,6 +61,14 @@ get_extended_data_from_NASIS_db <- function(SS=TRUE, nullFragsAreZero=TRUE, stri
     q.diagnostic <- gsub(pattern = '_View_1', replacement = '', x = q.diagnostic, fixed = TRUE)
   }
   
+  q.restriction <- "SELECT peiidref as peiid, resdept, resdepb, resthk_l, resthk_r, resthk_h, reskind, reshard
+FROM perestrictions_View_1 As prf
+	ORDER BY prf.peiidref, prf.resdept;"
+  
+  # toggle selected set vs. local DB
+  if(SS == FALSE) {
+    q.restriction <- gsub(pattern = '_View_1', replacement = '', x = q.restriction, fixed = TRUE)
+  }
   
   # TODO: convert this to simplifyFragmentData
   q.surf.rf.summary <- "SELECT pedon_View_1.peiid, 
@@ -185,7 +193,14 @@ LEFT OUTER JOIN (
   if(SS == FALSE) {
     q.rf.data <- gsub(pattern = '_View_1', replacement = '', x = q.rf.data, fixed = TRUE)
   }
-
+  
+  q.art.data <- paste0("SELECT p.phiid, huartvol, huartsize_l, huartsize_r, huartsize_h,
+              huartkind, huartco, huartshp, huartrnd, huartpen, huartsafety, huartper, 
+                       recwlupdated, recuseriidref, phhuartiid 
+                       FROM (
+                       SELECT DISTINCT phiid FROM phorizon_View_1
+                       ) as p LEFT OUTER JOIN phhuarts ", ifelse(SS, "_View_1","") , 
+                       " ON p.phiid = phiidref;")
   
   # new phfrags summary SQL
   q.rf.data.v2 <- "
@@ -368,17 +383,16 @@ LEFT OUTER JOIN (
     q.hz.dessuf <- gsub(pattern = '_View_1', replacement = '', x = q.hz.dessuf, fixed = TRUE)
   }
 	
-
-	
-	# setup connection local NASIS
-	channel <- RODBC::odbcDriverConnect(connection=getOption('soilDB.NASIS.credentials'))
+  channel <- .openNASISchannel()
 	
 	# exec queries
 	d.ecosite <- RODBC::sqlQuery(channel, q.ecosite, stringsAsFactors=FALSE)
 	d.diagnostic <- RODBC::sqlQuery(channel, q.diagnostic, stringsAsFactors=FALSE)
+	d.restriction <- RODBC::sqlQuery(channel, q.restriction, stringsAsFactors=FALSE)
+
 	d.rf.data <- RODBC::sqlQuery(channel, q.rf.data, stringsAsFactors=FALSE)
-	
 	d.rf.data.v2 <- RODBC::sqlQuery(channel, q.rf.data.v2, stringsAsFactors=FALSE)
+	d.art.data <- uncode(RODBC::sqlQuery(channel, q.art.data, stringsAsFactors=FALSE))
 	
 	d.surf.rf.summary <- RODBC::sqlQuery(channel, q.surf.rf.summary, stringsAsFactors=FALSE)
 	d.hz.texmod <- RODBC::sqlQuery(channel, q.hz.texmod, stringsAsFactors=FALSE)
@@ -392,6 +406,7 @@ LEFT OUTER JOIN (
 
 	## uncode the ones that need that here
 	d.diagnostic <- uncode(d.diagnostic, stringsAsFactors = stringsAsFactors)
+	d.restriction <- uncode(d.restriction, stringsAsFactors = stringsAsFactors)
 	d.rf.data    <- uncode(d.rf.data, stringsAsFactors = stringsAsFactors)
 	d.hz.texmod  <- uncode(d.hz.texmod, stringsAsFactors = stringsAsFactors)
 	# https://github.com/ncss-tech/soilDB/issues/53
@@ -428,8 +443,15 @@ LEFT OUTER JOIN (
 	  d.photolink$imagename <- basename(d.photolink$imagepath)
 	}
 
+	d.rf.summary <- simplifyFragmentData(d.rf.data, id.var='phiid', nullFragsAreZero = nullFragsAreZero)
+	
 	# summarize rock fragment data
 	if(nrow(d.rf.data) > 0) {
+	  # keep track of UNIQUE original phiids so that we can optionally fill NA with 0 in a second pass
+	  all.ids <- unique(d.rf.data[, 'phiid', drop=FALSE])
+	  
+	  # left join
+	  d.rf.summary <- join(all.ids, d.rf.summary, by='phiid', type='left')
 	  
 	  ## basic checks for problematic data
 	  
@@ -439,22 +461,10 @@ LEFT OUTER JOIN (
 	    msg <- sprintf('-> QC: some fragsize_h values == 76mm, may be mis-classified as cobbles [%i / %i records]', length(qc.idx), nrow(d.rf.data))
 	    message(msg)
 	  }
-	  
-	  
-	  # the results have 1 row / phiid
-	  # note: if all fragvol are NA then the result is NULL
-	  d.rf.summary <- simplifyFragmentData(d.rf.data, id.var='phiid', nullFragsAreZero = nullFragsAreZero)
-	  
-	  # second-pass of replacing NULL frags with 0
-	  # this is required because horizons missing rows in the phfrags table will result in NA
-	  # after subsequent LEFT JOINS
-	  if(nullFragsAreZero) {
-	    # keep track of UNIQUE original phiids so that we can optionally fill NA with 0 in a second pass
-	    all.ids <- unique(d.rf.data[, 'phiid', drop=FALSE])
-	    
-	    # left join and replace NA with 0
-	    d.rf.summary <- join(all.ids, d.rf.summary, by='phiid', type='left')
-	    
+
+	}
+	
+	if(nullFragsAreZero) {
 	    # iterate over every column except for the ID
 	    nm <- names(d.rf.summary)
 	    nm <- nm[grep('phiid', nm, fixed = TRUE, invert = TRUE)]
@@ -463,10 +473,32 @@ LEFT OUTER JOIN (
 	    for(v in nm) {
 	      d.rf.summary[[v]] <- ifelse(is.na(d.rf.summary[[v]]), 0, d.rf.summary[[v]])
 	    }
-	  }
+	}
+	
+	# artifact summary
+	d.art.summary <- simplifyArtifactData(d.art.data, id.var='phiid', nullFragsAreZero = nullFragsAreZero)
+	
+	if(nrow(d.art.data) > 0) {	  
 	  
-	} else {
-	  d.rf.summary <- NULL
+	  art.all.ids <- unique(d.art.data[, 'phiid', drop=FALSE])
+	  d.art.summary <- join(art.all.ids, d.art.summary, by='phiid', type='left')
+	  
+	  # recent NSSH changes to gravel/cobble threshold 76mm -> 75mm
+	  qc.idx <- which(d.art.data$huartsize_h == 76)
+	  if(length(qc.idx) > 0) {
+	    msg <- sprintf('-> QC: some huartsize_h values == 76mm, may be mis-classified as cobbles [%i / %i records]', length(qc.idx), nrow(d.art.data))
+	    message(msg)
+	  }
+  }
+	
+	if(nullFragsAreZero) {
+	  nm <- names(d.art.summary)
+	  nm <- nm[grep("phiid", nm, fixed = TRUE, invert = TRUE)]
+	  
+	  # a for-loop seems fine
+	  for(v in nm) {
+	    d.art.summary[[v]] <- ifelse(is.na(d.art.summary[[v]]), 0, d.art.summary[[v]])
+	  }
 	}
 	
 	# r.rf.data.v2 nullFragsAreZero = TRUE
@@ -479,9 +511,11 @@ LEFT OUTER JOIN (
 	# return a list of results
 	return(list(ecositehistory=d.ecosite,
 							diagnostic=d.diagnostic, 
-							diagHzBoolean=d.diag.boolean, 
+							diagHzBoolean=d.diag.boolean,
+							restriction=d.restriction,
 							frag_summary=d.rf.summary, 
 							frag_summary_v2 = d.rf.data.v2, 
+							art_summary=d.art.summary,
 							surf_frag_summary=d.surf.rf.summary, 
 							texmodifier=d.hz.texmod, 
 							geomorph=d.geomorph, 
