@@ -5,6 +5,12 @@ test_that("SDA_query() works", {
   
   skip_if_offline()
   
+  # hack for in-house testing only
+  # WWW services aren't always available and will cause CRAN to drop our package if tests fail
+  if(! soilDB:::.local_NASIS_defined()) {
+    skip("in-house testing only")
+  }
+  
   ## sample data
   
   # single-table result
@@ -25,8 +31,8 @@ test_that("SDA_query() works", {
   
   
   # standard request
-  expect_match(class(x.1), 'data.frame')
-  expect_match(class(x.2), 'list')
+  expect_true(inherits(x.1, 'data.frame'))
+  expect_true(inherits(x.2, 'list'))
 
 })
 
@@ -34,6 +40,12 @@ test_that("SDA_query() returns expected result", {
   
   skip_if_offline()
   
+  # hack for in-house testing only
+  # WWW services aren't always available and will cause CRAN to drop our package if tests fail
+  if(! soilDB:::.local_NASIS_defined()) {
+    skip("in-house testing only")
+  }
+  
   # table dimensions
   expect_equal(nrow(x.1), 1)
   expect_equal(ncol(x.1), 2)
@@ -49,6 +61,12 @@ test_that("SDA_query() SQL error / no results -> NULL", {
   
   skip_if_offline()
   
+  # hack for in-house testing only
+  # WWW services aren't always available and will cause CRAN to drop our package if tests fail
+  if(! soilDB:::.local_NASIS_defined()) {
+    skip("in-house testing only")
+  }
+  
   # bad SQL should result in a local error
   expect_error(SDA_query("SELECT this from that"))
   
@@ -63,10 +81,16 @@ test_that("SDA_spatialQuery() simple spatial query, tabular results", {
   
   skip_if_offline()
   
+  # hack for in-house testing only
+  # WWW services aren't always available and will cause CRAN to drop our package if tests fail
+  if(! soilDB:::.local_NASIS_defined()) {
+    skip("in-house testing only")
+  }
+  
   res <- SDA_spatialQuery(p, what = 'mukey')
   
   # testing known values
-  expect_match(class(res), 'data.frame')
+  expect_true(inherits(res, 'data.frame'))
   expect_equal(nrow(res), 1)
   expect_match(res$muname, 'Diablo')
   
@@ -77,10 +101,16 @@ test_that("SDA_spatialQuery() simple spatial query, spatial results", {
 
   skip_if_offline()
   
+  # hack for in-house testing only
+  # WWW services aren't always available and will cause CRAN to drop our package if tests fail
+  if(! soilDB:::.local_NASIS_defined()) {
+    skip("in-house testing only")
+  }
+  
   res <- SDA_spatialQuery(p, what = 'geom')
   
   # testing known values
-  expect_match(class(res), 'SpatialPolygonsDataFrame')
+  expect_true(inherits(res, 'SpatialPolygonsDataFrame'))
   expect_equal(nrow(res), 1)
   
 })
@@ -89,6 +119,12 @@ test_that("SDA_query() interprets column names", {
   
   skip_if_offline()
   
+  # hack for in-house testing only
+  # WWW services aren't always available and will cause CRAN to drop our package if tests fail
+  if(! soilDB:::.local_NASIS_defined()) {
+    skip("in-house testing only")
+  }
+  
   # x.3 is from the component table
   expect_equal(
     names(x.3), 
@@ -103,16 +139,22 @@ test_that("SDA_query() interprets data type correctly", {
   
   skip_if_offline()
   
+  # hack for in-house testing only
+  # WWW services aren't always available and will cause CRAN to drop our package if tests fail
+  if(! soilDB:::.local_NASIS_defined()) {
+    skip("in-house testing only")
+  }
+  
   # x.3 is from the component table
-  expect_equal(class(x.3$mukey), 'integer')
-  expect_equal(class(x.3$cokey), 'integer')
-  expect_equal(class(x.3$compkind), 'character')
-  expect_equal(class(x.3$comppct_r), 'integer')
-  expect_equal(class(x.3$majcompflag), 'character')
-  expect_equal(class(x.3$elev_r), 'integer')
-  expect_equal(class(x.3$slope_r), 'numeric')
-  expect_equal(class(x.3$wei), 'integer')
-  expect_equal(class(x.3$weg), 'integer')
+  expect_true(inherits(x.3$mukey, 'integer'))
+  expect_true(inherits(x.3$cokey, 'integer'))
+  expect_true(inherits(x.3$compkind, 'character'))
+  expect_true(inherits(x.3$comppct_r, 'integer'))
+  expect_true(inherits(x.3$majcompflag, 'character'))
+  expect_true(inherits(x.3$elev_r, 'integer'))
+  expect_true(inherits(x.3$slope_r, 'numeric'))
+  expect_true(inherits(x.3$wei, 'integer'))
+  expect_true(inherits(x.3$weg, 'integer'))
   
 })
 
@@ -122,8 +164,14 @@ test_that("SDA_query() works with multi-line records", {
 
   skip_if_offline()
   
+  # hack for in-house testing only
+  # WWW services aren't always available and will cause CRAN to drop our package if tests fail
+  if(! soilDB:::.local_NASIS_defined()) {
+    skip("in-house testing only")
+  }
+  
   # https://github.com/ncss-tech/soilDB/issues/28
-  expect_match(class(x.4), 'data.frame')
+  expect_true(inherits(x.4, 'data.frame'))
   expect_true(nrow(x.4) == 6)
 
 })
